@@ -6,7 +6,8 @@ from office.api.image import *
 class TestImage(unittest.TestCase):
     def test_add_watermark(self):
         add_watermark(file='../test_files/images/0816.jpg', mark='python-office',output_path=r'../test_output/img_output')
-
+    def test_com_img(self):
+        compress_image()
     def test_down4img(self):
         down4img(url='https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg',output_path=r'D:\download\xunlei')
 
